@@ -5,6 +5,7 @@ from datetime import datetime
 from django.contrib.auth.models import AnonymousUser
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
+from django.core.exceptions import ValidationError
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.utils.translation import ugettext as _
@@ -17,10 +18,12 @@ from openslides.projector.api import (get_active_slide, reset_countdown,
                                       update_projector, update_projector_overlay)
 from openslides.projector.models import SlideMixin
 from openslides.utils.exceptions import OpenSlidesError
+from openslides.utils.models import AbsoluteUrlMixin
 from openslides.utils.person.models import PersonField
+from openslides.utils.utils import to_roman
 
 
-class Item(SlideMixin, MPTTModel):
+class Item(SlideMixin, AbsoluteUrlMixin, MPTTModel):
     """
     An Agenda Item
 
@@ -35,6 +38,11 @@ class Item(SlideMixin, MPTTModel):
         (AGENDA_ITEM, ugettext_lazy('Agenda item')),
         (ORGANIZATIONAL_ITEM, ugettext_lazy('Organizational item')))
 
+    item_number = models.CharField(blank=True, max_length=255, verbose_name=ugettext_lazy("Number"))
+    """
+    Number of agenda item.
+    """
+
     title = models.CharField(null=True, max_length=255, verbose_name=ugettext_lazy("Title"))
     """
     Title of the agenda item.
@@ -115,6 +123,16 @@ class Item(SlideMixin, MPTTModel):
         if self.parent and self.parent.is_active_slide():
             update_projector()
 
+    def clean(self):
+        """
+        Ensures that the children of orga items are only orga items.
+        """
+        if self.type == self.AGENDA_ITEM and self.parent is not None and self.parent.type == self.ORGANIZATIONAL_ITEM:
+            raise ValidationError(_('Agenda items can not be child elements of an organizational item.'))
+        if self.type == self.ORGANIZATIONAL_ITEM and self.get_descendants().filter(type=self.AGENDA_ITEM).exists():
+            raise ValidationError(_('Organizational items can not have agenda items as child elements.'))
+        return super(Item, self).clean()
+
     def __unicode__(self):
         return self.get_title()
 
@@ -124,9 +142,9 @@ class Item(SlideMixin, MPTTModel):
 
         The link can be detail, update or delete.
         """
-        if link == 'detail' or link == 'view':
+        if link == 'detail':
             url = reverse('item_view', args=[str(self.id)])
-        elif link == 'update' or link == 'edit':
+        elif link == 'update':
             url = reverse('item_edit', args=[str(self.id)])
         elif link == 'delete':
             url = reverse('item_delete', args=[str(self.id)])
@@ -146,7 +164,8 @@ class Item(SlideMixin, MPTTModel):
         Return the title of this item.
         """
         if not self.content_object:
-            return self.title
+            item_no = self.item_no
+            return '%s %s' % (item_no, self.title) if item_no else self.title
         try:
             return self.content_object.get_agenda_title()
         except AttributeError:
@@ -283,6 +302,41 @@ class Item(SlideMixin, MPTTModel):
             value = False
         return value
 
+    @property
+    def item_no(self):
+        if self.item_number:
+            item_no = '%s %s' % (config['agenda_number_prefix'], self.item_number)
+        else:
+            item_no = None
+        return item_no
+
+    def calc_item_no(self):
+        """
+        Returns the number of this agenda item.
+        """
+        if self.type == self.AGENDA_ITEM:
+            if self.is_root_node():
+                if config['agenda_numeral_system'] == 'arabic':
+                    return str(self._calc_sibling_no())
+                else:  # config['agenda_numeral_system'] == 'roman'
+                    return to_roman(self._calc_sibling_no())
+            else:
+                return '%s.%s' % (self.parent.calc_item_no(), self._calc_sibling_no())
+        else:
+            return ''
+
+    def _calc_sibling_no(self):
+        """
+        Counts all siblings on the same level which are AGENDA_ITEMs.
+        """
+        sibling_no = 0
+        prev_sibling = self.get_previous_sibling()
+        while prev_sibling is not None:
+            if prev_sibling.type == self.AGENDA_ITEM:
+                sibling_no += 1
+            prev_sibling = prev_sibling.get_previous_sibling()
+        return sibling_no + 1
+
 
 class SpeakerManager(models.Manager):
     def add(self, person, item):
@@ -298,7 +352,7 @@ class SpeakerManager(models.Manager):
         return self.create(item=item, person=person, weight=weight + 1)
 
 
-class Speaker(models.Model):
+class Speaker(AbsoluteUrlMixin, models.Model):
     """
     Model for the Speaker list.
     """
@@ -347,11 +401,14 @@ class Speaker(models.Model):
         return unicode(self.person)
 
     def get_absolute_url(self, link='detail'):
-        if link == 'detail' or link == 'view':
-            return self.person.get_absolute_url('detail')
-        if link == 'delete':
-            return reverse('agenda_speaker_delete',
-                           args=[self.item.pk, self.pk])
+        if link == 'detail':
+            url = self.person.get_absolute_url('detail')
+        elif link == 'delete':
+            url = reverse('agenda_speaker_delete',
+                          args=[self.item.pk, self.pk])
+        else:
+            url = super(Speaker, self).get_absolute_url(link)
+        return url
 
     def check_and_update_projector(self):
         """
