@@ -2,26 +2,45 @@
 # TODO: Rename all views and template names
 
 from datetime import datetime, timedelta
+from json import dumps
 
 from django.contrib import messages
+from django.contrib.contenttypes.models import ContentType
+from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.core.urlresolvers import reverse
 from django.db import transaction
 from django.db.models import Model
+from django.template.loader import render_to_string
+from django.utils.datastructures import SortedDict
+from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
 from django.utils.translation import ugettext_lazy
 from reportlab.platypus import Paragraph
 
 from openslides.config.api import config
-from openslides.projector.api import get_active_slide, update_projector
-from openslides.projector.projector import Widget
+from openslides.projector.api import (
+    get_active_object,
+    get_active_slide,
+    get_projector_overlays_js,
+    get_overlays,
+    update_projector)
 from openslides.utils.exceptions import OpenSlidesError
 from openslides.utils.pdf import stylesheet
-from openslides.utils.template import Tab
 from openslides.utils.utils import html_strong
-from openslides.utils.views import (CreateView, DeleteView, FormView, PDFView,
-                                    RedirectView, SingleObjectMixin,
-                                    TemplateView, UpdateView)
+from openslides.utils.views import (
+    AjaxMixin,
+    CreateView,
+    CSVImportView,
+    DeleteView,
+    FormView,
+    PDFView,
+    QuestionView,
+    RedirectView,
+    SingleObjectMixin,
+    TemplateView,
+    UpdateView)
 
+from .csv_import import import_agenda_items
 from .forms import AppendSpeakerForm, ItemForm, ItemOrderForm, RelatedItemForm
 from .models import Item, Speaker
 
@@ -30,7 +49,7 @@ class Overview(TemplateView):
     """
     Show all agenda items, and update their range via post.
     """
-    permission_required = 'agenda.can_see_agenda'
+    required_permission = 'agenda.can_see_agenda'
     template_name = 'agenda/overview.html'
 
     def get_context_data(self, **kwargs):
@@ -116,8 +135,14 @@ class Overview(TemplateView):
                     parent = Item.objects.get(id=form.cleaned_data['parent'])
                 except Item.DoesNotExist:
                     parent = None
-                item.weight = form.cleaned_data['weight']
+                else:
+                    if item.type == item.AGENDA_ITEM and parent.type == item.ORGANIZATIONAL_ITEM:
+                        transaction.rollback()
+                        messages.error(
+                            request, _('Agenda items can not be child elements of an organizational item.'))
+                        break
                 item.parent = parent
+                item.weight = form.cleaned_data['weight']
                 Model.save(item)
             else:
                 transaction.rollback()
@@ -147,15 +172,15 @@ class AgendaItemView(SingleObjectMixin, FormView):
     context_object_name = 'item'
     form_class = AppendSpeakerForm
 
-    def has_permission(self, request, *args, **kwargs):
+    def check_permission(self, request, *args, **kwargs):
         """
         Checks if the user has the required permission.
         """
         if self.get_object().type == Item.ORGANIZATIONAL_ITEM:
-            permission = request.user.has_perm('agenda.can_see_orga_items')
+            check_permission = request.user.has_perm('agenda.can_see_orga_items')
         else:
-            permission = request.user.has_perm('agenda.can_see_agenda')
-        return permission
+            check_permission = request.user.has_perm('agenda.can_see_agenda')
+        return check_permission
 
     def get_context_data(self, **kwargs):
         self.object = self.get_object()
@@ -185,7 +210,7 @@ class SetClosed(RedirectView, SingleObjectMixin):
     """
     Close or open an item.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     allow_ajax = True
     url_name = 'item_overview'
     model = Item
@@ -212,7 +237,7 @@ class ItemUpdate(UpdateView):
     """
     Update an existing item.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     template_name = 'agenda/edit.html'
     model = Item
     context_object_name = 'item'
@@ -231,7 +256,7 @@ class ItemCreate(CreateView):
     """
     Create a new item.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     template_name = 'agenda/edit.html'
     model = Item
     context_object_name = 'item'
@@ -244,7 +269,7 @@ class ItemDelete(DeleteView):
     """
     Delete an item.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     model = Item
     question_url_name = 'item_overview'
     success_url_name = 'item_overview'
@@ -300,7 +325,7 @@ class CreateRelatedAgendaItemView(SingleObjectMixin, RedirectView):
     This view is only for subclassing in views of related apps. You
     have to define 'model = ....'
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     url_name = 'item_overview'
     url_name_args = []
 
@@ -318,11 +343,27 @@ class CreateRelatedAgendaItemView(SingleObjectMixin, RedirectView):
         self.item = Item.objects.create(content_object=self.object)
 
 
+class AgendaNumberingView(QuestionView):
+    required_permission = 'agenda.can_manage_agenda'
+    question_url_name = 'item_overview'
+    url_name = 'item_overview'
+    question_message = ugettext_lazy('Do you really want to generate agenda numbering? Manually added item numbers will be overwritten!')
+    url_name_args = []
+
+    def on_clicked_yes(self):
+        for item in Item.objects.all():
+            item.item_number = item.calc_item_no()
+            item.save()
+
+    def get_final_message(self):
+        return ugettext_lazy('The agenda has been numbered.')
+
+
 class AgendaPDF(PDFView):
     """
     Create a full agenda-PDF.
     """
-    permission_required = 'agenda.can_see_agenda'
+    required_permission = 'agenda.can_see_agenda'
     filename = ugettext_lazy('Agenda')
     document_title = ugettext_lazy('Agenda')
 
@@ -342,7 +383,7 @@ class SpeakerAppendView(SingleObjectMixin, RedirectView):
     """
     Set the request.user to the speaker list.
     """
-    permission_required = 'agenda.can_be_speaker'
+    required_permission = 'agenda.can_be_speaker'
     url_name = 'item_view'
     model = Item
 
@@ -366,7 +407,7 @@ class SpeakerDeleteView(DeleteView):
     success_url_name = 'item_view'
     question_url_name = 'item_view'
 
-    def has_permission(self, request, *args, **kwargs):
+    def check_permission(self, request, *args, **kwargs):
         """
         Check the permission to delete a speaker.
         """
@@ -410,7 +451,7 @@ class SpeakerSpeakView(SingleObjectMixin, RedirectView):
     """
     Mark the speaking person.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     url_name = 'item_view'
     model = Item
 
@@ -437,7 +478,7 @@ class SpeakerEndSpeachView(SingleObjectMixin, RedirectView):
     """
     The speach of the actual speaker is finished.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     url_name = 'item_view'
     model = Item
 
@@ -463,7 +504,7 @@ class SpeakerListCloseView(SingleObjectMixin, RedirectView):
     """
     View to close and reopen a list of speakers.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     model = Item
     reopen = False
     url_name = 'item_view'
@@ -483,7 +524,7 @@ class SpeakerChangeOrderView(SingleObjectMixin, RedirectView):
 
     Has to be called as post-request with the new order of the speaker ids.
     """
-    permission_required = 'agenda.can_manage_agenda'
+    required_permission = 'agenda.can_manage_agenda'
     model = Item
     url_name = 'item_view'
 
@@ -534,14 +575,20 @@ class CurrentListOfSpeakersView(RedirectView):
         """
         Returns the current Item, or None, if the current Slide is not an Agenda Item.
         """
-        active_slide = get_active_slide()
-        if active_slide['callback'] == 'agenda':
-            try:
-                return Item.objects.get(pk=active_slide.get('pk', None))
-            except Item.DoesNotExist:
-                return None
+        slide = get_active_object()
+        if slide is None or isinstance(slide, Item):
+            # No Slide or an agenda item is active
+            item = slide
         else:
-            return None
+            # A related Item is active
+            try:
+                item = Item.objects.filter(
+                    content_type=ContentType.objects.get_for_model(slide),
+                    object_id=slide.pk)[0]
+            except IndexError:
+                item = None
+
+        return item
 
     def get_redirect_url(self):
         """
@@ -570,7 +617,7 @@ class CurrentListOfSpeakersView(RedirectView):
             messages.error(request, _(
                 'There is no list of speakers for the current slide. '
                 'Please choose the agenda item manually from the agenda.'))
-            return reverse('dashboard')
+            return reverse('core_dashboard')
 
         if self.set_speaker:
             if item.speaker_list_closed:
@@ -614,61 +661,123 @@ class CurrentListOfSpeakersView(RedirectView):
 
         if item.type == Item.ORGANIZATIONAL_ITEM:
             if reverse_to_dashboard or not self.request.user.has_perm('agenda.can_see_orga_items'):
-                return reverse('dashboard')
+                return reverse('core_dashboard')
             else:
                 return reverse('item_view', args=[item.pk])
         else:
             if reverse_to_dashboard or not self.request.user.has_perm('agenda.can_see_agenda'):
-                return reverse('dashboard')
+                return reverse('core_dashboard')
             else:
                 return reverse('item_view', args=[item.pk])
 
 
-def register_tab(request):
+class CurrentListOfSpeakersProjectorView(AjaxMixin, TemplateView):
     """
-    Registers the agenda tab.
+    View with the current list of speakers depending on the active slide.
+    Usefule for the projector.
     """
-    selected = request.path.startswith('/agenda/')
-    return Tab(
-        title=_('Agenda'),
-        app='agenda',
-        url=reverse('item_overview'),
-        permission=(request.user.has_perm('agenda.can_see_agenda') or
-                    request.user.has_perm('agenda.can_manage_agenda')),
-        selected=selected)
+    template_name = 'agenda/current_list_of_speakers_projector.html'
+
+    def get(self, request, *args, **kwargs):
+        """
+        Returns response object depending on request type (ajax or normal).
+        """
+        if request.is_ajax():
+            value = self.ajax_get(request, *args, **kwargs)
+        else:
+            value = super(CurrentListOfSpeakersProjectorView, self).get(request, *args, **kwargs)
+        return value
+
+    def get_item(self):
+        """
+        Returns the item of the current slide is an agenda item slide or a
+        slide of a related model else returns None.
+        """
+        slide_object = get_active_object()
+        if slide_object is None or isinstance(slide_object, Item):
+            item = slide_object
+        else:
+            # TODO: If there is more than one item, use the first one in the
+            #       mptt tree that is not closed.
+            try:
+                item = Item.objects.filter(
+                    content_type=ContentType.objects.get_for_model(slide_object),
+                    object_id=slide_object.pk)[0]
+            except IndexError:
+                item = None
+        return item
+
+    def get_content(self):
+        """
+        Returns the content of this slide.
+        """
+        item = self.get_item()
+        if item is None:
+            content = mark_safe('<h1>%s</h1><i>%s</i>\n' % (_('List of speakers'), _('Not available.')))
+        else:
+            content_dict = {
+                'title': item.get_title(),
+                'item': item,
+                'list_of_speakers': item.get_list_of_speakers(
+                    old_speakers_count=config['agenda_show_last_speakers'])}
+            content = render_to_string('agenda/item_slide_list_of_speaker.html', content_dict)
+        return content
+
+    def get_overlays_and_overlay_js(self):
+        """
+        Returns the overlays and their JavaScript for this slide as a
+        two-tuple. The overlay 'agenda_speaker' is always excluded.
+
+        The required JavaScript fot this view is inserted.
+        """
+        overlays = get_overlays(only_active=True)
+        overlays.pop('agenda_speaker', None)
+        overlay_js = get_projector_overlays_js(as_json=True)
+        # Note: The JavaScript content of overlay 'agenda_speaker' is not
+        #       excluded because this overlay has no such content at the moment.
+        extra_js = SortedDict()
+        extra_js['load_file'] = static('js/agenda_current_list_of_speakers_projector.js')
+        extra_js['call'] = 'reloadListOfSpeakers();'
+        extra_js = dumps(extra_js)
+        overlay_js.append(extra_js)
+        return overlays, overlay_js
+
+    def get_context_data(self, **context):
+        """
+        Returns the context for the projector template. Contains the content
+        of this slide.
+        """
+        overlays, overlay_js = self.get_overlays_and_overlay_js()
+        return super(CurrentListOfSpeakersProjectorView, self).get_context_data(
+            content=self.get_content(),
+            overlays=overlays,
+            overlay_js=overlay_js,
+            **context)
+
+    def get_ajax_context(self, **context):
+        """
+        Returns the context including the slide content for ajax response. The
+        overlay 'agenda_speaker' is always excluded.
+        """
+        overlay_dict = {}
+        for overlay in get_overlays().values():
+            if overlay.is_active() and overlay.name != 'agenda_speaker':
+                overlay_dict[overlay.name] = {
+                    'html': overlay.get_projector_html(),
+                    'javascript': overlay.get_javascript()}
+            else:
+                overlay_dict[overlay.name] = None
+        return super(CurrentListOfSpeakersProjectorView, self).get_ajax_context(
+            content=self.get_content(),
+            overlays=overlay_dict,
+            **context)
 
 
-def get_widgets(request):
+class ItemCSVImportView(CSVImportView):
     """
-    Returns the agenda widget for the projector tab.
+    Imports agenda items from an uploaded csv file.
     """
-    active_slide = get_active_slide()
-    if active_slide['callback'] == 'agenda':
-        agenda_is_active = active_slide.get('pk', 'agenda') == 'agenda'
-        active_type = active_slide.get('type', 'text')
-    else:
-        agenda_is_active = None
-        active_type = None
-
-    return [
-        Widget(
-            request,
-            name='agenda',
-            display_name=_('Agenda'),
-            template='agenda/widget.html',
-            context={
-                'agenda_is_active': agenda_is_active,
-                'items': Item.objects.all(),
-                'active_type': active_type},
-            permission_required='projector.can_manage_projector',
-            default_column=1,
-            default_weight=20),
-
-        Widget(
-            request,
-            name='append_to_list_of_speakers',
-            display_name=_('List of speakers'),
-            template='agenda/speaker_widget.html',
-            permission_required=('agenda.can_be_speaker', 'agenda.can_manage_agenda'),  # Short hack only for OpenSlides >=1.5.1, <1.6.0
-            default_column=1,
-            default_weight=30)]
+    import_function = staticmethod(import_agenda_items)
+    required_permission = 'agenda.can_manage_agenda'
+    success_url_name = 'item_overview'
+    template_name = 'agenda/item_form_csv_import.html'
