@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 
 import os
+import copy
 
 from django.utils.translation import ugettext_lazy
 
 from openslides.utils.main import filesystem2unicode
-
+from openslides.utils.plugins import collect_plugins
 
 SITE_ROOT = os.path.realpath(os.path.dirname(__file__))
 
@@ -52,12 +53,6 @@ STATIC_ROOT = filesystem2unicode(os.path.join(SITE_ROOT, '../collected-site-stat
 # Examples: "http://static.lawrence.com", "http://example.com/static/"
 STATIC_URL = '/static/'
 
-# Additional directories containing static files (not application specific)
-# Examples: "/home/media/lawrence.com/extra-static/"
-STATICFILES_DIRS = (
-    filesystem2unicode(os.path.join(SITE_ROOT, 'static')),
-)
-
 STATICFILES_FINDERS = (
     'django.contrib.staticfiles.finders.FileSystemFinder',
     'django.contrib.staticfiles.finders.AppDirectoriesFinder',
@@ -81,14 +76,6 @@ MIDDLEWARE_CLASSES = (
 
 ROOT_URLCONF = 'openslides.urls'
 
-TEMPLATE_DIRS = (
-    # Put strings here, like "/home/html/django_templates" or
-    # "C:/www/django/templates".
-    # Always use forward slashes, even on Windows.
-    # Don't forget to use absolute paths, not relative paths.
-    filesystem2unicode(os.path.join(SITE_ROOT, 'templates')),
-)
-
 INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -98,6 +85,7 @@ INSTALLED_APPS = (
     'django.contrib.humanize',
     'mptt',
     'haystack',  # full-text-search
+    'ckeditor',
     'openslides.poll',
     'openslides.core',
     'openslides.account',
@@ -117,6 +105,8 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     'django.core.context_processors.i18n',
     'django.core.context_processors.static',
     'openslides.utils.auth.anonymous_context_additions',
+    'openslides.utils.main_menu.main_menu_entries',
+    'openslides.core.chatbox.chat_messages_context_processor',
 )
 
 CACHES = {
@@ -139,3 +129,43 @@ HAYSTACK_CONNECTIONS = {
 
 # Haystack updates search index after each save/delete action by apps
 HAYSTACK_SIGNAL_PROCESSOR = 'haystack.signals.RealtimeSignalProcessor'
+
+# Adds all automaticly collected plugins
+INSTALLED_PLUGINS = collect_plugins()
+
+# CKeditor settings
+CKEDITOR_DEFAULT_CONFIG = {'toolbar': 'Full',
+                           'contentsCss': '/static/css/ckeditor.css',
+                           'bodyClass': 'ckeditor_html',
+                           'allowedContent':
+                               'h1 h2 h3 pre b i u strike em; '
+
+                               # A workaround for the problem described in http://dev.ckeditor.com/ticket/10192
+                               # Hopefully, the problem will be solved in the final version of CKEditor 4.1
+                               # If so, then {margin-left} can be removed
+                               'p{margin-left}; '
+
+                               'a[!href]; '
+                               'ol ul{list-style}; '
+                               'li; '
+                               'span{color,background-color}; ',
+                           'removePlugins': 'save, print, preview, pagebreak, templates, showblocks, magicline',
+                           'toolbar_Full': [
+                               {'name': 'document',    'items': ['Source', '-', 'Save', 'DocProps', 'Preview', 'Print', '-', 'Templates']},
+                               {'name': 'clipboard',   'items': ['Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo']},
+                               {'name': 'editing',     'items': ['Find', 'Replace', '-', 'SpellChecker', 'Scayt']},
+                               {'name': 'basicstyles', 'items': ['Bold', 'Italic', 'Underline', 'Strike', '-', 'RemoveFormat']},
+                               {'name': 'paragraph',   'items': ['NumberedList', 'BulletedList', '-', 'Pre', 'InsertPre']},
+                               {'name': 'links',       'items': ['Link', 'Unlink']},
+                               {'name': 'styles',      'items': ['Format', 'TextColor', 'BGColor']},
+                               {'name': 'tools',       'items': ['Maximize', 'ShowBlocks', '-', 'About']}
+                           ]}
+CKEDITOR_IMG_CONFIG = copy.deepcopy(CKEDITOR_DEFAULT_CONFIG)
+CKEDITOR_IMG_CONFIG['allowedContent'] += 'img; '
+CKEDITOR_IMG_CONFIG['toolbar_Full'].append({'name': 'images', 'items': ['Image']})
+
+CKEDITOR_UPLOAD_PATH = 'ckeditor'
+CKEDITOR_CONFIGS = {
+    'default': CKEDITOR_DEFAULT_CONFIG,
+    'images': CKEDITOR_IMG_CONFIG,
+}
