@@ -1,37 +1,73 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.motion.signals
-    ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    Signals for the motion app.
-
-    :copyright: (c) 2011-2013 by the OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
-
-from django.dispatch import receiver
 from django import forms
-from django.utils.translation import ugettext as _, ugettext_lazy, ugettext_noop
+from django.dispatch import receiver
+from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy, ugettext_noop
 
+from openslides.config.api import ConfigGroup, ConfigGroupedCollection, ConfigVariable
 from openslides.config.signals import config_signal
-from openslides.config.api import ConfigVariable, ConfigPage
 from openslides.core.signals import post_database_setup
+from openslides.poll.models import PERCENT_BASE_CHOICES
 
-from .models import Workflow, State
+from .models import State, Workflow
 
 
-@receiver(config_signal, dispatch_uid='setup_motion_config_page')
-def setup_motion_config_page(sender, **kwargs):
+@receiver(config_signal, dispatch_uid='setup_motion_config')
+def setup_motion_config(sender, **kwargs):
     """
     Motion config variables.
     """
+    # General
+    motion_workflow = ConfigVariable(
+        name='motion_workflow',
+        default_value='1',
+        form_field=forms.ChoiceField(
+            widget=forms.Select(),
+            label=ugettext_lazy('Workflow of new motions'),
+            required=True,
+            choices=[(str(workflow.pk), ugettext_lazy(workflow.name)) for workflow in Workflow.objects.all()]))
+    motion_identifier = ConfigVariable(
+        name='motion_identifier',
+        default_value='per_category',
+        form_field=forms.ChoiceField(
+            widget=forms.Select(),
+            required=True,
+            label=ugettext_lazy('Identifier'),
+            choices=[
+                ('per_category', ugettext_lazy('Numbered per category')),
+                ('serially_numbered', ugettext_lazy('Serially numbered')),
+                ('manually', ugettext_lazy('Set it manually'))]))
+    motion_preamble = ConfigVariable(
+        name='motion_preamble',
+        default_value=_('The assembly may decide,'),
+        translatable=True,
+        form_field=forms.CharField(
+            widget=forms.TextInput(),
+            required=False,
+            label=ugettext_lazy('Motion preamble')))
     motion_stop_submitting = ConfigVariable(
         name='motion_stop_submitting',
         default_value=False,
         form_field=forms.BooleanField(
             label=ugettext_lazy('Stop submitting new motions by non-staff users'),
             required=False))
+    motion_allow_disable_versioning = ConfigVariable(
+        name='motion_allow_disable_versioning',
+        default_value=False,
+        form_field=forms.BooleanField(
+            label=ugettext_lazy('Allow to disable versioning'),
+            required=False))
+    group_general = ConfigGroup(
+        title=ugettext_lazy('General'),
+        variables=(
+            motion_workflow,
+            motion_identifier,
+            motion_preamble,
+            motion_stop_submitting,
+            motion_allow_disable_versioning))
+
+    # Supporters
     motion_min_supporters = ConfigVariable(
         name='motion_min_supporters',
         default_value=0,
@@ -46,13 +82,19 @@ def setup_motion_config_page(sender, **kwargs):
         form_field=forms.BooleanField(
             label=ugettext_lazy('Remove all supporters of a motion if a submitter edits his motion in early state'),
             required=False))
-    motion_preamble = ConfigVariable(
-        name='motion_preamble',
-        default_value=_('The assembly may decide,'),
-        form_field=forms.CharField(
-            widget=forms.TextInput(),
+    group_supporters = ConfigGroup(
+        title=ugettext_lazy('Supporters'),
+        variables=(motion_min_supporters, motion_remove_supporters))
+
+    # Voting and ballot papers
+    motion_poll_100_percent_base = ConfigVariable(
+        name='motion_poll_100_percent_base',
+        default_value='WITHOUT_INVALID',
+        form_field=forms.ChoiceField(
+            widget=forms.Select(),
             required=False,
-            label=ugettext_lazy('Motion preamble')))
+            label=ugettext_lazy('The 100 % base of a voting result consists of'),
+            choices=PERCENT_BASE_CHOICES))
     motion_pdf_ballot_papers_selection = ConfigVariable(
         name='motion_pdf_ballot_papers_selection',
         default_value='CUSTOM_NUMBER',
@@ -72,9 +114,15 @@ def setup_motion_config_page(sender, **kwargs):
             required=False,
             min_value=1,
             label=ugettext_lazy('Custom number of ballot papers')))
+    group_ballot_papers = ConfigGroup(
+        title=ugettext_lazy('Voting and ballot papers'),
+        variables=(motion_poll_100_percent_base, motion_pdf_ballot_papers_selection, motion_pdf_ballot_papers_number))
+
+    # PDF
     motion_pdf_title = ConfigVariable(
         name='motion_pdf_title',
         default_value=_('Motions'),
+        translatable=True,
         form_field=forms.CharField(
             widget=forms.TextInput(),
             required=False,
@@ -90,50 +138,17 @@ def setup_motion_config_page(sender, **kwargs):
         name='motion_pdf_paragraph_numbering',
         default_value=False,
         form_field=forms.BooleanField(
-            label=ugettext_lazy('Show paragraph numbering'),
+            label=ugettext_lazy('Show paragraph numbering (only in PDF)'),
             required=False))
-    motion_allow_disable_versioning = ConfigVariable(
-        name='motion_allow_disable_versioning',
-        default_value=False,
-        form_field=forms.BooleanField(
-            label=ugettext_lazy('Allow to disable versioning'),
-            required=False))
-    motion_workflow = ConfigVariable(
-        name='motion_workflow',
-        default_value=1,
-        form_field=forms.ChoiceField(
-            widget=forms.Select(),
-            label=ugettext_lazy('Workflow of new motions'),
-            required=True,
-            choices=[(workflow.pk, ugettext_lazy(workflow.name)) for workflow in Workflow.objects.all()]))
-    motion_identifier = ConfigVariable(
-        name='motion_identifier',
-        default_value='per_category',
-        form_field=forms.ChoiceField(
-            widget=forms.Select(),
-            required=True,
-            label=ugettext_lazy('Identifier'),
-            choices=[
-                ('per_category', ugettext_lazy('Numbered per category')),
-                ('serially_numbered', ugettext_lazy('Serially numbered')),
-                ('manually', ugettext_lazy('Set it manually'))]))
+    group_pdf = ConfigGroup(
+        title=ugettext_lazy('PDF'),
+        variables=(motion_pdf_title, motion_pdf_preamble, motion_pdf_paragraph_numbering))
 
-    return ConfigPage(title=ugettext_noop('Motion'),
-                      url='motion',
-                      required_permission='config.can_manage',
-                      weight=30,
-                      variables=(motion_stop_submitting,
-                                 motion_min_supporters,
-                                 motion_remove_supporters,
-                                 motion_preamble,
-                                 motion_pdf_ballot_papers_selection,
-                                 motion_pdf_ballot_papers_number,
-                                 motion_pdf_title,
-                                 motion_pdf_preamble,
-                                 motion_pdf_paragraph_numbering,
-                                 motion_allow_disable_versioning,
-                                 motion_workflow,
-                                 motion_identifier))
+    return ConfigGroupedCollection(
+        title=ugettext_noop('Motion'),
+        url='motion',
+        weight=30,
+        groups=(group_general, group_supporters, group_ballot_papers, group_pdf))
 
 
 @receiver(post_database_setup, dispatch_uid='motion_create_builtin_workflows')
