@@ -1,23 +1,27 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.urls
-    ~~~~~~~~~~~~~~~
-
-    Global URL list for OpenSlides.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 
 from django.conf import settings
-from django.conf.urls import patterns, url, include
-from django.utils.importlib import import_module
+from django.conf.urls import include, patterns, url
 
+from openslides.core.views import ErrorView
+from openslides.utils.plugins import get_urlpatterns
 
-handler500 = 'openslides.utils.views.server_error'
+handler403 = ErrorView.as_view(status_code=403)
+handler404 = ErrorView.as_view(status_code=404)
+handler500 = ErrorView.as_view(status_code=500)
 
-urlpatterns = patterns('',
+urlpatterns = []
+
+js_info_dict = {'packages': []}
+
+for plugin in settings.INSTALLED_PLUGINS:
+    plugin_urlpatterns = get_urlpatterns(plugin)
+    if plugin_urlpatterns:
+        urlpatterns += plugin_urlpatterns
+        js_info_dict['packages'].append(plugin)
+
+urlpatterns += patterns(
+    '',
     (r'^agenda/', include('openslides.agenda.urls')),
     (r'^motion/', include('openslides.motion.urls')),
     (r'^assignment/', include('openslides.assignment.urls')),
@@ -26,45 +30,32 @@ urlpatterns = patterns('',
     (r'^config/', include('openslides.config.urls')),
     (r'^projector/', include('openslides.projector.urls')),
     (r'^i18n/', include('django.conf.urls.i18n')),
+    (r'^ckeditor/', include('ckeditor.urls')),
 )
 
-js_info_dict = {'packages': [],}
-
-for plugin in settings.INSTALLED_PLUGINS:
-    try:
-        mod = import_module(plugin + '.urls')
-    except ImportError:
-        continue
-
-    plugin_name = mod.__name__.split('.')[0]
-    urlpatterns += patterns('', (r'^%s/' % plugin_name, include('%s.urls'
-                                                                % plugin)))
-    js_info_dict['packages'].append(plugin)
-
-urlpatterns += patterns('',
+# TODO: move this patterns into core or the participant app
+urlpatterns += patterns(
+    '',
     (r'^jsi18n/$', 'django.views.i18n.javascript_catalog', js_info_dict),
 
     url(r'^login/$',
         'openslides.participant.views.login',
-        name='user_login',
-    ),
+        name='user_login'),
 
     url(r'^logout/$',
         'django.contrib.auth.views.logout_then_login',
-        name='user_logout',
-    ),
+        name='user_logout'),
 
     url(r'^usersettings/$',
         'openslides.participant.views.user_settings',
-        name='user_settings',
-    ),
+        name='user_settings'),
 
     url(r'^usersettings/changepassword/$',
         'openslides.participant.views.user_settings_password',
-        name='password_change',
-    ),
+        name='password_change'),
 )
 
-urlpatterns += patterns('',
+urlpatterns += patterns(
+    '',
     (r'^', include('openslides.core.urls')),
 )
