@@ -1,40 +1,31 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.utils.pdf
-    ~~~~~~~~~~~~~~~~~~~~
-
-    Additional definitions for creating PDF documents.
-
-    :copyright: 2011, 2012 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 
 from datetime import datetime
 from os.path import join as path_join
 
+from django.conf import settings
+from django.utils import formats
+from django.utils.translation import ugettext as _
 from reportlab.lib import colors
-from reportlab.lib.styles import StyleSheet1, ParagraphStyle
+from reportlab.lib.styles import ParagraphStyle, StyleSheet1
 from reportlab.lib.units import cm
 from reportlab.pdfbase import pdfmetrics
 from reportlab.pdfbase.ttfonts import TTFont
 from reportlab.rl_config import defaultPageSize
 
-from django.conf import settings
-from django.utils import formats
-from django.utils.translation import ugettext as _
-
 from openslides.config.api import config
 
-
 # register new truetype fonts
 pdfmetrics.registerFont(TTFont(
-    'Ubuntu', path_join(settings.SITE_ROOT, 'static/fonts/Ubuntu-R.ttf')))
+    'Ubuntu', path_join(settings.SITE_ROOT, 'core/static/fonts/Ubuntu-R.ttf')))
 pdfmetrics.registerFont(TTFont(
-    'Ubuntu-Bold', path_join(settings.SITE_ROOT, 'static/fonts/Ubuntu-B.ttf')))
+    'Ubuntu-Bold', path_join(settings.SITE_ROOT, 'core/static/fonts/Ubuntu-B.ttf')))
 pdfmetrics.registerFont(TTFont(
-    'Ubuntu-Italic', path_join(settings.SITE_ROOT, 'static/fonts/Ubuntu-RI.ttf')))
+    'Ubuntu-Italic', path_join(settings.SITE_ROOT, 'core/static/fonts/Ubuntu-RI.ttf')))
+pdfmetrics.registerFont(TTFont(
+    'circlefont', path_join(settings.SITE_ROOT, 'core/static/fonts/circle.ttf')))
 
+pdfmetrics.registerFontFamily('Ubuntu', normal='Ubuntu', bold='Ubuntu-Bold', italic='Ubuntu-Italic')
 
 # set style information
 PAGE_HEIGHT = defaultPageSize[1]
@@ -45,6 +36,7 @@ PAGE_WIDTH = defaultPageSize[0]
 stylesheet = StyleSheet1()
 stylesheet.add(ParagraphStyle(
     name='Normal',
+    fontName='Ubuntu',
     fontSize=10,
     leading=12,
 ))
@@ -54,6 +46,11 @@ stylesheet.add(ParagraphStyle(
     leading=14,
     spaceAfter=15
 ))
+stylesheet.add(ParagraphStyle(
+    name='Paragraph12',
+    parent=stylesheet['Paragraph'],
+    fontSize=12
+))
 stylesheet.add(ParagraphStyle(
     name='InnerParagraph',
     parent=stylesheet['Normal'],
@@ -140,7 +137,7 @@ stylesheet.add(ParagraphStyle(
     parent=stylesheet['Bold'],
     fontSize=10,
     leading=20,
-))
+), alias='h4')
 stylesheet.add(ParagraphStyle(
     name='Item',
     parent=stylesheet['Normal'],
@@ -192,71 +189,48 @@ stylesheet.add(ParagraphStyle(name='Ballot_option',
                               leading=24,
                               leftIndent=30),
                )
+stylesheet.add(ParagraphStyle(name='Ballot_option_name_YNA',
+                              parent=stylesheet['Ballot_option'],
+                              leading=14),
+               )
 stylesheet.add(ParagraphStyle(name='Ballot_option_name',
-                              parent=stylesheet['Normal'],
-                              fontSize=12,
-                              leading=15,
-                              leftIndent=30),
+                              parent=stylesheet['Ballot_option_name_YNA'],
+                              leading=17),
                )
-stylesheet.add(ParagraphStyle(name='Ballot_option_group',
-                              parent=stylesheet['Normal'],
+
+stylesheet.add(ParagraphStyle(name='Ballot_option_suffix_YNA',
+                              parent=stylesheet['Ballot_option_name_YNA'],
                               fontSize=8,
-                              leading=15,
-                              leftIndent=30),
+                              leading=11),
                )
-stylesheet.add(ParagraphStyle(name='Ballot_option_YNA',
-                              parent=stylesheet['Normal'],
-                              fontSize=12,
-                              leading=15,
-                              leftIndent=49,
+stylesheet.add(ParagraphStyle(name='Ballot_option_suffix',
+                              parent=stylesheet['Ballot_option_suffix_YNA'],
+                              leading=16,
+                              leftIndent=48),
+               )
+stylesheet.add(ParagraphStyle(name='Ballot_option_circle_YNA',
+                              parent=stylesheet['Ballot_option_name_YNA'],
+                              leftIndent=48,
                               spaceAfter=18),
                )
-stylesheet.add(ParagraphStyle(name='Ballot_option_group_right',
-                              parent=stylesheet['Normal'],
-                              fontSize=8,
-                              leading=16,
-                              leftIndent=49),
-               )
 # Password paper stylesheets
-stylesheet.add(ParagraphStyle(name='Password_title',
-                              parent=stylesheet['Ballot_title'],
+stylesheet.add(ParagraphStyle(name='formfield',
+                              parent=stylesheet['Normal'],
+                              fontSize=12,
+                              leading=18,
                               leftIndent=0),
                )
-stylesheet.add(ParagraphStyle(name='Password_subtitle',
-                              parent=stylesheet['Ballot_subtitle'],
-                              leftIndent=0),
-               )
-stylesheet.add(ParagraphStyle(name='Monotype',
+stylesheet.add(ParagraphStyle(name='formfield_value',
                               parent=stylesheet['Normal'],
                               fontName='Courier',
                               fontSize=12,
-                              leading=24,
-                              leftIndent=0),
+                              leading=28,
+                              leftIndent=10),
                )
-stylesheet.add(ParagraphStyle(name='Badge_title',
-                              parent=stylesheet['Bold'],
-                              fontSize=16,
-                              leading=22,
-                              leftIndent=30),
+stylesheet.add(ParagraphStyle(name='qrcode_comment',
+                              parent=stylesheet['Small'],
+                              spaceBefore=6),
                )
-stylesheet.add(ParagraphStyle(name='Badge_subtitle',
-                              parent=stylesheet['Normal'],
-                              fontSize=12,
-                              leading=24,
-                              leftIndent=30),
-               )
-stylesheet.add(ParagraphStyle(
-    name='Badge_italic',
-    parent=stylesheet['Italic'],
-    fontSize=12,
-    leading=24,
-    leftIndent=30,
-))
-stylesheet.add(ParagraphStyle(
-    name='Badge_qrcode',
-    fontSize=12,
-    leftIndent=190,
-))
 
 
 def firstPage(canvas, doc):
